#include "valuedialog.h"
#include "../shared/selectionmodel.h"
#include <QListView>
#include <QVBoxLayout>

ValueDialog::ValueDialog(QWidget *parent) :
    QDialog(parent),
    m_model(0),
    m_view(new QListView(this))
{
    this->setAttribute(Qt::WA_DeleteOnClose, true);

    QVBoxLayout *vbox = new QVBoxLayout(this);
    vbox->addWidget(m_view);

    this->connect(m_view, SIGNAL(clicked(QModelIndex)), this, SLOT(onItemClicked(QModelIndex)));
}

ValueDialog::~ValueDialog() {}

SelectionModel* ValueDialog::model() const {
    return m_model;
}

void ValueDialog::setModel(SelectionModel *model) {
    m_model = model;
    m_view->setModel(model);

    if (model->rowCount() > 0) {
        m_view->setMinimumHeight(m_view->sizeHintForRow(0) * 5);
    }
}

void ValueDialog::setValue(const QVariant &value) {
    if (!m_model) {
        return;
    }

    bool found = false;
    int i = 0;

    while ((!found) && (i < m_model->rowCount())) {
        found = m_model->data(m_model->index(i, 0), SelectionRoles::ValueRole) == value;

        if (found) {
            m_view->setCurrentIndex(m_model->index(i, 0));
        }

        i++;
    }

    if (!found) {
        m_view->setCurrentIndex(m_model->index(0, 0));
    }
}

QVariant ValueDialog::currentValue() {
    return !m_model ? QVariant() : m_model->data(m_view->currentIndex(), SelectionRoles::ValueRole);
}

void ValueDialog::onItemClicked(const QModelIndex &index) {
    emit valueChanged(index.data(SelectionRoles::ValueRole));
}
